@@ -4,6 +4,7 @@ from . import cv
 from . import nlp
 from . import line
 from . import chatbot
+from . import googlesheet
 
 __all__ = [
     'openapi',
@@ -11,5 +12,6 @@ __all__ = [
     'cv',
     'nlp',
     'line',
-    'chatbot'
+    'chatbot',
+    'googlesheet'
 ]
\ No newline at end of file
