@@ -12,7 +12,7 @@ class userstate():
     def getuserstate(self,userid):
         userstate = self.dbcollection.find_one({"userId": userid})
         if userstate is None:
-            userstate = {"userId": user}
+            userstate = {"userId": userid}
             self.dbcollection.insert_one(userstate)
         return userstate
 
